@@ -4,7 +4,7 @@
 # may not use this file except in compliance with the License. A copy of
 # the License is located at
 #
-# http://aws.amazon.com/apache2.0/
+# http://www.apache.org/licenses/LICENSE-2.0
 #
 # or in the "license" file accompanying this file. This file is
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
@@ -26,6 +26,8 @@ from .logout import logout
 from .lookup import lookup
 from .populate_profiles import populate_profiles
 from .roles import roles
+from .run_as import run_as
+from .console import launch, get_config_token, launch_from_config
 
 @click.group(name="aws-sso-util")
 @click.version_option(version=__version__, message='%(version)s')
@@ -44,6 +46,16 @@ cli.add_command(login)
 cli.add_command(logout)
 cli.add_command(roles)
 cli.add_command(check)
+cli.add_command(run_as)
+
+@cli.group()
+def console():
+    """Commands for launching the AWS console in a browser."""
+    pass
+
+console.add_command(launch)
+console.add_command(get_config_token)
+console.add_command(launch_from_config)
 
 @cli.group()
 def admin():
